<?php
/**
 * @package  geeSearch_Plus Admin Notices
 */

if ( !defined( 'GEE_SP_VERSION' ) ) {
	header( 'HTTP/1.0 403 Forbidden' );
	die;
}

/**
 *  Class to generate notices on WordPress Admin
 */
class Gee_Search_Plus_Admin_Notices {

	static private $admin_notices = array();
	static private $dismissed_notices = array();

	/**
	 * Class constructor
	 */
	function __construct() {

		add_action( 'admin_notices', array( $this, 'dismiss_notice' ), 50 );
		add_action( 'admin_notices', array( $this, 'admin_notice' ), 100 );

		// add donation link
		add_action( 'admin_notices', array( $this, 'add_donation_notice'), 10 );

	}

	/**
	 * Outputs the admin notices generated by the plugin
	 *
	 * @return void
	 */
	function admin_notice() {

		if( empty( self::$admin_notices ) ) {
			return;
		}

		//don't display a message if use has dismissed the message for this version
		self::$dismissed_notices = (array)get_transient( 'geesearch_dismissed_notices' );

		foreach( self::$admin_notices as $notice ) {

			if( false === $this->_maybe_show_notice( $notice ) ) {
				continue;
			}

			echo '<div id="message" class="'. esc_attr( $notice['class'] ).'">';

			if( !empty( $notice['title'] ) ) {
				echo '<h3>'. esc_html( $notice['title'] ) .'</h3>';
			}

			echo wpautop( $notice['message'] );

			if( !empty( $notice['dismiss'] ) ) {

				$dismiss = esc_attr( $notice['dismiss'] );

				$url = add_query_arg( array( 'gsp-dismiss' => wp_create_nonce( 'gspdismiss' ), 'notice' => $dismiss ) );

				echo wpautop( '<a href="'. $url .'" data-notice="'. $dismiss . '" class="button-small button button-secondary">'. esc_html__( 'Dismiss', 'gee-search-plus' ).'</a>' );
			}

			echo '<div class="clear"></div>';
			echo '</div>';

		}

		//reset the notices handler
		self::$admin_notices = array();
	}



	function _maybe_show_notice( $notice ) {

    	// There are no dismissed notices.
    	if( empty( self::$dismissed_notices ) ) {
    		return true;
    	}

    	// Has the
    	$is_dismissed = !empty( $notice['dismiss'] ) && in_array( $notice['dismiss'], self::$dismissed_notices );

    	return $is_dismissed ? false : true;
    }


    function dismiss_notice() {

    	// No dismiss sent
    	if( empty( $_GET['gsp-dismiss'] ) ) {
    		return;
    	}

    	// Invalid nonce
    	if( !wp_verify_nonce( $_GET['gsp-dismiss'], 'gspdismiss' ) ) {
    		return;
    	}

    	$notice_id = esc_attr( $_GET['notice'] );

    	//don't display a message if use has dismissed the message for this version
    	$dismissed_notices = (array)get_transient( 'geesearch_dismissed_notices' );

    	$dismissed_notices[] = $notice_id;

    	$dismissed_notices = array_unique( $dismissed_notices );

    	// Remind users every 12 weeks
    	set_transient( 'geesearch_dismissed_notices', $dismissed_notices, WEEK_IN_SECONDS * 12 );

    }

    /**
	 * Add a notice to be displayed in the admin.
	 * @param array $notice Array with `class` and `message` keys. The message is not escaped.
	 */
	public static function add_notice( $notice = array() ) {

		if( !isset( $notice['message'] ) ) {
			return;
		}

		$notice['class'] = empty( $notice['class'] ) ? 'error' : $notice['class'];

		self::$admin_notices[] = $notice;
	}


	function add_donation_notice() {

		if( ! apply_filters( 'geesearchplus_please_donate', true ) ) {
			return;
		}

		$screen = get_current_screen();

		if( $screen->id != 'plugins' ) {
			return;
		}

		$message = 'Do you want to help making this plugin even better? <a href="https://www.paypal.com/cgi-bin/webscr?cmd=_xclick&business=paypal%40gomo%2ept&item_name=geeSearch%20Plus%20plugin&no_shipping=1&cn=Donation%20Notes&tax=0&currency_code=EUR&bn=PP%2dDonationsBF&charset=UTF%2d8" target="_blank"><span class="dashicons dashicons-heart"></span><strong>Donate now!</strong></a>';

		self::add_notice( array(
			'message' => $message,
			'class'	=> 'updated',
			'title' => 'geeSearch Plus',
			'dismiss' => sha1( 'geeSearch_donation' ),
		) );
	}

}

new Gee_Search_Plus_Admin_Notices;